@@ -48,19 +48,16 @@ build_index(PopplerDocument* poppler_document, girara_tree_node_t* root, Poppler
       continue;
     }
 
-    gchar* markup = g_markup_escape_text(action->any.title, -1);
-    zathura_index_element_t* index_element = zathura_index_element_new(markup);
-
-    g_free(markup);
-
+    zathura_index_element_t* index_element = zathura_index_element_new(action->any.title);
     if (index_element == NULL) {
       poppler_action_free(action);
       continue;
     }
 
-    zathura_rectangle_t rect = { 0, 0, 0, 0 };
-    index_element->link = poppler_link_to_zathura_link(poppler_document, action, rect);
+    zathura_rectangle_t rect = {0, 0, 0, 0};
+    index_element->link      = poppler_link_to_zathura_link(poppler_document, action, rect);
     if (index_element->link == NULL) {
+      zathura_index_element_free(index_element);
       poppler_action_free(action);
       continue;
     }
